pub struct PatternRow {}Expand description
Pattern Row = play this pattern, with these settings, when playing this row of the arrangement. Pretty simple.
Does not have any new methods – create the struct by hand.
Fields
pattern_id: u8Which Pattern should be played at this point. Patterns are indexed from 0 (A01) -> 256 (P16).
Validation
Checked by the Self::validate method
repetitions: u8unused_1: u8mute_mask: u8How track muting is applied during this arrangement row.
Validation
Not checked by the Self::validate method
unused_2: u8tempo_1: u8First part of the Tempo mask for this row.
Needs to be combined with tempo_2 to work out the actual tempo (not sure how it works yet).
Validation
Not checked by the Self::validate method
tempo_2: u8Second part of the Tempo mask for this row.
Needs to be combined with tempo_1 to work out the actual tempo (not sure how it works yet).
Validation
Not checked by the Self::validate method
scene_a: u8Which scene is assigned to Scene slot A when this arrangement row is playing.
Validation
Checked by the Self::validate method
scene_b: u8Which scene is assigned to Scene slot B when this arrangement row is playing.
Validation
Checked by the Self::validate method
unused_3: u8offset: u8Which trig to start Playing the pattern on. todo: is there a maximum for this?
Validation
Not (currently) checked by the Self::validate method
unused_4: u8length: u8How many trigs to play the pattern for.
Note that this value always has offset added to it.
So a length on the machine display of 64 when the offset is 32 will result in a value of 96 in the file data.
todo: is there a maximum for this?
Validation
Not (currently) checked by the Self::validate method
midi_transpose: [u8; 8]MIDI Track transposes for all 8 midi channels.
- 0 -> no transpose
- 1 -> 48 values are positive transpose settings
- 255 (-1) -> 207 (-48) values are negative transpose settings.
Validation
Checked by the Self::validate method
Implementations
Sourceimpl PatternRow
impl PatternRow