Enum LoopMode

pub enum LoopMode {
    Off = 0,
    Normal = 1,
    PingPong = 2,
}
Sample attributes Loop mode options. See Octatrack Manaul section 13.2.4 ATTRIBUTES

Variants



Off = 0

Loop points are ignored and sample will never loop.



Normal = 1

Loop by starting again at the loop start position once playback of the sample reaches loop end.



PingPong = 2

Loop by continuously reversing once playback of the sample reaches loop end/loop start.