#[repr(u8)]pub enum BankId {
Show 16 variants
A = 0,
B = 1,
C = 2,
D = 3,
E = 4,
F = 5,
G = 6,
H = 7,
I = 8,
J = 9,
K = 10,
L = 11,
M = 12,
N = 13,
O = 14,
P = 15,
}Expand description
Identifier values for Banks, allowing for panic-free indexing via id* methods.
Variants
A = 0
B = 1
C = 2
D = 3
E = 4
F = 5
G = 6
H = 7
I = 8
J = 9
K = 10
L = 11
M = 12
N = 13
O = 14
P = 15
Implementations
Sourceimpl BankId
impl BankId
Sourcepub fn as_index(&self) -> usize
pub fn as_index(&self) -> usize
Get the identifier variant as a zero-indexed integer for raw array indexing
Sourcepub fn file_name(&self) -> String
pub fn file_name(&self) -> String
Get the relevant file name path component for a crate::banks::BankFile given the
identifier’s value
Sourcepub fn file_stem(&self, state: &SavedState) -> String
pub fn file_stem(&self, state: &SavedState) -> String
Get the relevant file stem path component for a crate::banks::BankFile given the
identifier’s value and some SavedState