pub enum SavedState {
Working,
Stored,
}Expand description
Identifier values for the saved state of some data / files.
Most “identifier” types in this module use a series of alphanumeric characters to
identify an instance in the same manner that the Octatrack uses,
e.g. TrackId::One or BankId::A
This SavedState “identifier” type is different.
It will never be used with id*() methods to access the members of a collection.
It is used in two locations to model Octatrack behaviour:
- Accessing the saved or unsaved set of
Partswithin aBankFilevia theparts()method. - Identifying which
ProjectFile,BankFile,ArrangementFileorMarkersFileshould be read from / written to.
Variants
Working
*.work files – working copy
Note on File Creates/Writes
Whole Project
Data is written to all *.work files when either a SYNC TO CARD or a SAVE PROJECT
operation is executed from the Octatrack’s Project menu.
Save Bank
Data is written to bank<ID>.work file each time the SAVE BANK operation is executed from
the Octatrack’s Project menu.
Save Arrangement
Data is written to arr<ID>.work file when the SAVE ARRANGEMENT operation is executed
from the Octatrack’s Arranger sub-menu.
Stored
*.strd files – restorable, stored copy.
Note on File Creates/Writes
Whole Project
Data is written to new *.strd files on the first SAVE PROJECT operation from
the Octatrack’s project menu.
Subsequent SAVE PROJECT operations then save to those same files.
Save Bank
A bank<ID>.strd file is created when the SAVE BANK operation is first executed from
the Octatrack’s Project menu.
Data is written to the bank<ID>.strd file each time the SAVE BANK operation is executed
from the Octatrack’s Project menu.
Save Arrangement
A arr<ID>.strd file is created when the SAVE ARRANGEMENT operation is first executed
from the Octatrack’s Arranger sub-menu.
Data is written to the arr<ID>.strd file each time the SAVE ARRANGEMENT operation is
executed from the Octatrack’s Arranger sub-menu.
Implementations
Sourceimpl SavedState
impl SavedState
Sourcepub fn file_extension(&self) -> String
pub fn file_extension(&self) -> String
Returns the relevant file extension for the saved state, for the files that support it.