pub struct AudioTrackMachineParamsSetupNeighbor {
pub unused_1: u8,
pub unused_2: u8,
pub unused_3: u8,
pub unused_4: u8,
pub unused_5: u8,
pub unused_6: u8,
}Expand description
An Audio Track’s Setup values for the Neighbor machine on the track. Should not contain any data.
Fields
unused_1: u8unused_2: u8unused_3: u8unused_4: u8unused_5: u8unused_6: u8Trait Implementations
Sourceimpl AsMut<AudioTrackMachineParamsSetupNeighbor> for AudioTrackMachineParamsSetupNeighbor
impl AsMut<AudioTrackMachineParamsSetupNeighbor> for AudioTrackMachineParamsSetupNeighbor
Sourcefn as_mut(&mut self) -> &mut AudioTrackMachineParamsSetupNeighbor
fn as_mut(&mut self) -> &mut AudioTrackMachineParamsSetupNeighbor
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackMachineParamsSetupNeighbor> for AudioTrackMachineParamsSetupNeighbor
impl AsRef<AudioTrackMachineParamsSetupNeighbor> for AudioTrackMachineParamsSetupNeighbor
Sourcefn as_ref(&self) -> &AudioTrackMachineParamsSetupNeighbor
fn as_ref(&self) -> &AudioTrackMachineParamsSetupNeighbor
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackMachineParamsSetupNeighbor
impl Clone for AudioTrackMachineParamsSetupNeighbor
Sourcefn clone(&self) -> AudioTrackMachineParamsSetupNeighbor
fn clone(&self) -> AudioTrackMachineParamsSetupNeighbor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackMachineParamsSetupNeighbor
Sourceimpl Default for AudioTrackMachineParamsSetupNeighbor
impl Default for AudioTrackMachineParamsSetupNeighbor
Sourcefn default() -> AudioTrackMachineParamsSetupNeighbor
fn default() -> AudioTrackMachineParamsSetupNeighbor
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AudioTrackMachineParamsSetupNeighbor
impl<'de> Deserialize<'de> for AudioTrackMachineParamsSetupNeighbor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackMachineParamsSetupNeighbor
Sourceimpl Ord for AudioTrackMachineParamsSetupNeighbor
impl Ord for AudioTrackMachineParamsSetupNeighbor
Sourcefn cmp(&self, other: &AudioTrackMachineParamsSetupNeighbor) -> Ordering
fn cmp(&self, other: &AudioTrackMachineParamsSetupNeighbor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AudioTrackMachineParamsSetupNeighbor
impl PartialOrd for AudioTrackMachineParamsSetupNeighbor
impl StructuralPartialEq for AudioTrackMachineParamsSetupNeighbor