pub struct AudioTrackMachineParamsSetupStd {
pub xloop: u8,
pub slic: u8,
pub len: u8,
pub rate: u8,
pub tstr: u8,
pub tsns: u8,
}Expand description
An Audio Track’s Setup values for the Static and Flex machine on the track (loop setting/slice setting/len setting etc.).
Fields
xloop: u8slic: u8len: u8rate: u8tstr: u8tsns: u8Trait Implementations
Sourceimpl AsMut<AudioTrackMachineParamsSetupStd> for AudioTrackMachineParamsSetupStd
impl AsMut<AudioTrackMachineParamsSetupStd> for AudioTrackMachineParamsSetupStd
Sourcefn as_mut(&mut self) -> &mut AudioTrackMachineParamsSetupStd
fn as_mut(&mut self) -> &mut AudioTrackMachineParamsSetupStd
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackMachineParamsSetupStd> for AudioTrackMachineParamsSetupStd
impl AsRef<AudioTrackMachineParamsSetupStd> for AudioTrackMachineParamsSetupStd
Sourcefn as_ref(&self) -> &AudioTrackMachineParamsSetupStd
fn as_ref(&self) -> &AudioTrackMachineParamsSetupStd
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackMachineParamsSetupStd
impl Clone for AudioTrackMachineParamsSetupStd
Sourcefn clone(&self) -> AudioTrackMachineParamsSetupStd
fn clone(&self) -> AudioTrackMachineParamsSetupStd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackMachineParamsSetupStd
Sourceimpl<'de> Deserialize<'de> for AudioTrackMachineParamsSetupStd
impl<'de> Deserialize<'de> for AudioTrackMachineParamsSetupStd
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackMachineParamsSetupStd
Sourceimpl Ord for AudioTrackMachineParamsSetupStd
impl Ord for AudioTrackMachineParamsSetupStd
Sourcefn cmp(&self, other: &AudioTrackMachineParamsSetupStd) -> Ordering
fn cmp(&self, other: &AudioTrackMachineParamsSetupStd) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AudioTrackMachineParamsSetupStd
impl PartialOrd for AudioTrackMachineParamsSetupStd
impl StructuralPartialEq for AudioTrackMachineParamsSetupStd