pub struct AudioTrackMachineParamsValuesNeighbor {
pub unused_1: u8,
pub unused_2: u8,
pub unused_3: u8,
pub unused_4: u8,
pub unused_5: u8,
pub unused_6: u8,
}Expand description
Values of an Audio Track’s parameters page for the Neighbor machine on the track. Should not contain any data.
Fields
unused_1: u8unused_2: u8unused_3: u8unused_4: u8unused_5: u8unused_6: u8Trait Implementations
Sourceimpl AsMut<AudioTrackMachineParamsValuesNeighbor> for AudioTrackMachineParamsValuesNeighbor
impl AsMut<AudioTrackMachineParamsValuesNeighbor> for AudioTrackMachineParamsValuesNeighbor
Sourcefn as_mut(&mut self) -> &mut AudioTrackMachineParamsValuesNeighbor
fn as_mut(&mut self) -> &mut AudioTrackMachineParamsValuesNeighbor
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackMachineParamsValuesNeighbor> for AudioTrackMachineParamsValuesNeighbor
impl AsRef<AudioTrackMachineParamsValuesNeighbor> for AudioTrackMachineParamsValuesNeighbor
Sourcefn as_ref(&self) -> &AudioTrackMachineParamsValuesNeighbor
fn as_ref(&self) -> &AudioTrackMachineParamsValuesNeighbor
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackMachineParamsValuesNeighbor
impl Clone for AudioTrackMachineParamsValuesNeighbor
Sourcefn clone(&self) -> AudioTrackMachineParamsValuesNeighbor
fn clone(&self) -> AudioTrackMachineParamsValuesNeighbor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackMachineParamsValuesNeighbor
Sourceimpl Default for AudioTrackMachineParamsValuesNeighbor
impl Default for AudioTrackMachineParamsValuesNeighbor
Sourcefn default() -> AudioTrackMachineParamsValuesNeighbor
fn default() -> AudioTrackMachineParamsValuesNeighbor
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AudioTrackMachineParamsValuesNeighbor
impl<'de> Deserialize<'de> for AudioTrackMachineParamsValuesNeighbor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackMachineParamsValuesNeighbor
Sourceimpl Ord for AudioTrackMachineParamsValuesNeighbor
impl Ord for AudioTrackMachineParamsValuesNeighbor
Sourcefn cmp(&self, other: &AudioTrackMachineParamsValuesNeighbor) -> Ordering
fn cmp(&self, other: &AudioTrackMachineParamsValuesNeighbor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AudioTrackMachineParamsValuesNeighbor
impl PartialOrd for AudioTrackMachineParamsValuesNeighbor
impl StructuralPartialEq for AudioTrackMachineParamsValuesNeighbor