pub struct AudioTrackMachineSlot {
pub static_slot_id: u8,
pub flex_slot_id: u8,
pub unused_1: u8,
pub unused_2: u8,
pub recorder_slot_id: u8,
}Expand description
Audio Tracks Machine Slot assignments. Sample Slots assigned for each machine. Also tracks the recording buffer sample slot assignment.
Fields
static_slot_id: u8flex_slot_id: u8unused_1: u8unused_2: u8recorder_slot_id: u8Trait Implementations
Sourceimpl AsMut<AudioTrackMachineSlot> for AudioTrackMachineSlot
impl AsMut<AudioTrackMachineSlot> for AudioTrackMachineSlot
Sourcefn as_mut(&mut self) -> &mut AudioTrackMachineSlot
fn as_mut(&mut self) -> &mut AudioTrackMachineSlot
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackMachineSlot> for AudioTrackMachineSlot
impl AsRef<AudioTrackMachineSlot> for AudioTrackMachineSlot
Sourcefn as_ref(&self) -> &AudioTrackMachineSlot
fn as_ref(&self) -> &AudioTrackMachineSlot
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackMachineSlot
impl Clone for AudioTrackMachineSlot
Sourcefn clone(&self) -> AudioTrackMachineSlot
fn clone(&self) -> AudioTrackMachineSlot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackMachineSlot
Sourceimpl Debug for AudioTrackMachineSlot
impl Debug for AudioTrackMachineSlot
Sourceimpl Default for AudioTrackMachineSlot
impl Default for AudioTrackMachineSlot
Sourceimpl<const N: usize> Defaults<Box<[AudioTrackMachineSlot; N]>> for AudioTrackMachineSlot
impl<const N: usize> Defaults<Box<[AudioTrackMachineSlot; N]>> for AudioTrackMachineSlot
Sourceimpl<const N: usize> Defaults<[AudioTrackMachineSlot; N]> for AudioTrackMachineSlot
impl<const N: usize> Defaults<[AudioTrackMachineSlot; N]> for AudioTrackMachineSlot
Sourceimpl<'de> Deserialize<'de> for AudioTrackMachineSlot
impl<'de> Deserialize<'de> for AudioTrackMachineSlot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackMachineSlot
Sourceimpl Hash for AudioTrackMachineSlot
impl Hash for AudioTrackMachineSlot
Sourceimpl Ord for AudioTrackMachineSlot
impl Ord for AudioTrackMachineSlot
Sourcefn cmp(&self, other: &AudioTrackMachineSlot) -> Ordering
fn cmp(&self, other: &AudioTrackMachineSlot) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AudioTrackMachineSlot
impl PartialEq for AudioTrackMachineSlot
Sourceimpl PartialOrd for AudioTrackMachineSlot
impl PartialOrd for AudioTrackMachineSlot
Sourceimpl Serialize for AudioTrackMachineSlot
impl Serialize for AudioTrackMachineSlot
impl StructuralPartialEq for AudioTrackMachineSlot