pub struct AudioTrackSceneLockPlayback {
pub param1: u8,
pub param2: u8,
pub param3: u8,
pub param4: u8,
pub param5: u8,
pub param6: u8,
}Expand description
A scene’s parameter assignments on the Playback/Machine page for an Audio Track.
Fields
param1: u8param2: u8param3: u8param4: u8param5: u8param6: u8Trait Implementations
Sourceimpl AsMut<AudioTrackSceneLockPlayback> for AudioTrackSceneLockPlayback
impl AsMut<AudioTrackSceneLockPlayback> for AudioTrackSceneLockPlayback
Sourcefn as_mut(&mut self) -> &mut AudioTrackSceneLockPlayback
fn as_mut(&mut self) -> &mut AudioTrackSceneLockPlayback
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackSceneLockPlayback> for AudioTrackSceneLockPlayback
impl AsRef<AudioTrackSceneLockPlayback> for AudioTrackSceneLockPlayback
Sourcefn as_ref(&self) -> &AudioTrackSceneLockPlayback
fn as_ref(&self) -> &AudioTrackSceneLockPlayback
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackSceneLockPlayback
impl Clone for AudioTrackSceneLockPlayback
Sourcefn clone(&self) -> AudioTrackSceneLockPlayback
fn clone(&self) -> AudioTrackSceneLockPlayback
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackSceneLockPlayback
Sourceimpl Debug for AudioTrackSceneLockPlayback
impl Debug for AudioTrackSceneLockPlayback
Sourceimpl<'de> Deserialize<'de> for AudioTrackSceneLockPlayback
impl<'de> Deserialize<'de> for AudioTrackSceneLockPlayback
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackSceneLockPlayback
Sourceimpl Hash for AudioTrackSceneLockPlayback
impl Hash for AudioTrackSceneLockPlayback
Sourceimpl Ord for AudioTrackSceneLockPlayback
impl Ord for AudioTrackSceneLockPlayback
Sourcefn cmp(&self, other: &AudioTrackSceneLockPlayback) -> Ordering
fn cmp(&self, other: &AudioTrackSceneLockPlayback) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AudioTrackSceneLockPlayback
impl PartialOrd for AudioTrackSceneLockPlayback
impl StructuralPartialEq for AudioTrackSceneLockPlayback