pub struct MidiTrackNoteParamsSetup {
pub chan: u8,
pub bank: u8,
pub prog: u8,
pub unused_1: u8,
pub sbank: u8,
pub unused_2: u8,
}Expand description
Values for a MIDI Track’s Note Setup page.
Fields
chan: u8bank: u8prog: u8unused_1: u8sbank: u8unused_2: u8Trait Implementations
Sourceimpl AsMut<MidiTrackNoteParamsSetup> for MidiTrackNoteParamsSetup
impl AsMut<MidiTrackNoteParamsSetup> for MidiTrackNoteParamsSetup
Sourcefn as_mut(&mut self) -> &mut MidiTrackNoteParamsSetup
fn as_mut(&mut self) -> &mut MidiTrackNoteParamsSetup
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<MidiTrackNoteParamsSetup> for MidiTrackNoteParamsSetup
impl AsRef<MidiTrackNoteParamsSetup> for MidiTrackNoteParamsSetup
Sourcefn as_ref(&self) -> &MidiTrackNoteParamsSetup
fn as_ref(&self) -> &MidiTrackNoteParamsSetup
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for MidiTrackNoteParamsSetup
impl Clone for MidiTrackNoteParamsSetup
Sourcefn clone(&self) -> MidiTrackNoteParamsSetup
fn clone(&self) -> MidiTrackNoteParamsSetup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MidiTrackNoteParamsSetup
Sourceimpl Debug for MidiTrackNoteParamsSetup
impl Debug for MidiTrackNoteParamsSetup
Sourceimpl Default for MidiTrackNoteParamsSetup
impl Default for MidiTrackNoteParamsSetup
Sourceimpl<'de> Deserialize<'de> for MidiTrackNoteParamsSetup
impl<'de> Deserialize<'de> for MidiTrackNoteParamsSetup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MidiTrackNoteParamsSetup
Sourceimpl Hash for MidiTrackNoteParamsSetup
impl Hash for MidiTrackNoteParamsSetup
Sourceimpl Ord for MidiTrackNoteParamsSetup
impl Ord for MidiTrackNoteParamsSetup
Sourcefn cmp(&self, other: &MidiTrackNoteParamsSetup) -> Ordering
fn cmp(&self, other: &MidiTrackNoteParamsSetup) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MidiTrackNoteParamsSetup
impl PartialEq for MidiTrackNoteParamsSetup
Sourceimpl PartialOrd for MidiTrackNoteParamsSetup
impl PartialOrd for MidiTrackNoteParamsSetup
Sourceimpl Serialize for MidiTrackNoteParamsSetup
impl Serialize for MidiTrackNoteParamsSetup
impl StructuralPartialEq for MidiTrackNoteParamsSetup