pub struct RecorderSetupProcessing {
pub fin: u8,
pub fout: u8,
pub ab: u8,
pub qrec: u8,
pub qpl: u8,
pub cd: u8,
}Expand description
Second page of settings controlling an Audio Track’s Recording Buffer configuration.
Fields
fin: u8fout: u8ab: u8qrec: u8qpl: u8cd: u8Trait Implementations
Sourceimpl AsMut<RecorderSetupProcessing> for RecorderSetupProcessing
impl AsMut<RecorderSetupProcessing> for RecorderSetupProcessing
Sourcefn as_mut(&mut self) -> &mut RecorderSetupProcessing
fn as_mut(&mut self) -> &mut RecorderSetupProcessing
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<RecorderSetupProcessing> for RecorderSetupProcessing
impl AsRef<RecorderSetupProcessing> for RecorderSetupProcessing
Sourcefn as_ref(&self) -> &RecorderSetupProcessing
fn as_ref(&self) -> &RecorderSetupProcessing
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for RecorderSetupProcessing
impl Clone for RecorderSetupProcessing
Sourcefn clone(&self) -> RecorderSetupProcessing
fn clone(&self) -> RecorderSetupProcessing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RecorderSetupProcessing
Sourceimpl Debug for RecorderSetupProcessing
impl Debug for RecorderSetupProcessing
Sourceimpl Default for RecorderSetupProcessing
impl Default for RecorderSetupProcessing
Sourceimpl<'de> Deserialize<'de> for RecorderSetupProcessing
impl<'de> Deserialize<'de> for RecorderSetupProcessing
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RecorderSetupProcessing
Sourceimpl Hash for RecorderSetupProcessing
impl Hash for RecorderSetupProcessing
Sourceimpl Ord for RecorderSetupProcessing
impl Ord for RecorderSetupProcessing
Sourcefn cmp(&self, other: &RecorderSetupProcessing) -> Ordering
fn cmp(&self, other: &RecorderSetupProcessing) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecorderSetupProcessing
impl PartialEq for RecorderSetupProcessing
Sourceimpl PartialOrd for RecorderSetupProcessing
impl PartialOrd for RecorderSetupProcessing
Sourceimpl Serialize for RecorderSetupProcessing
impl Serialize for RecorderSetupProcessing
impl StructuralPartialEq for RecorderSetupProcessing