pub struct RecorderSetupSources {
pub in_ab: u8,
pub in_cd: u8,
pub rlen: u8,
pub trig: u8,
pub src3: u8,
pub xloop: u8,
}Expand description
First page of settings controlling an Audio Track’s Recording Buffer configuration.
Fields
in_ab: u8in_cd: u8rlen: u864 is MAX. 63 and lower are actual values.
trig: u8src3: u8internal recording source
xloop: u8Trait Implementations
Sourceimpl AsMut<RecorderSetupSources> for RecorderSetupSources
impl AsMut<RecorderSetupSources> for RecorderSetupSources
Sourcefn as_mut(&mut self) -> &mut RecorderSetupSources
fn as_mut(&mut self) -> &mut RecorderSetupSources
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<RecorderSetupSources> for RecorderSetupSources
impl AsRef<RecorderSetupSources> for RecorderSetupSources
Sourcefn as_ref(&self) -> &RecorderSetupSources
fn as_ref(&self) -> &RecorderSetupSources
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for RecorderSetupSources
impl Clone for RecorderSetupSources
Sourcefn clone(&self) -> RecorderSetupSources
fn clone(&self) -> RecorderSetupSources
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RecorderSetupSources
Sourceimpl Debug for RecorderSetupSources
impl Debug for RecorderSetupSources
Sourceimpl Default for RecorderSetupSources
impl Default for RecorderSetupSources
Sourceimpl<'de> Deserialize<'de> for RecorderSetupSources
impl<'de> Deserialize<'de> for RecorderSetupSources
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RecorderSetupSources
Sourceimpl Hash for RecorderSetupSources
impl Hash for RecorderSetupSources
Sourceimpl Ord for RecorderSetupSources
impl Ord for RecorderSetupSources
Sourcefn cmp(&self, other: &RecorderSetupSources) -> Ordering
fn cmp(&self, other: &RecorderSetupSources) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecorderSetupSources
impl PartialEq for RecorderSetupSources
Sourceimpl PartialOrd for RecorderSetupSources
impl PartialOrd for RecorderSetupSources
Sourceimpl Serialize for RecorderSetupSources
impl Serialize for RecorderSetupSources
impl StructuralPartialEq for RecorderSetupSources