pub struct AudioTrackParameterLockPlayback {
pub param1: u8,
pub param2: u8,
pub param3: u8,
pub param4: u8,
pub param5: u8,
pub param6: u8,
}Expand description
A Trig’s parameter locks on the Playback/Machine page for an Audio Track.
Fields
param1: u8param2: u8param3: u8param4: u8param5: u8param6: u8Trait Implementations
Sourceimpl AsMut<AudioTrackParameterLockPlayback> for AudioTrackParameterLockPlayback
impl AsMut<AudioTrackParameterLockPlayback> for AudioTrackParameterLockPlayback
Sourcefn as_mut(&mut self) -> &mut AudioTrackParameterLockPlayback
fn as_mut(&mut self) -> &mut AudioTrackParameterLockPlayback
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<AudioTrackParameterLockPlayback> for AudioTrackParameterLockPlayback
impl AsRef<AudioTrackParameterLockPlayback> for AudioTrackParameterLockPlayback
Sourcefn as_ref(&self) -> &AudioTrackParameterLockPlayback
fn as_ref(&self) -> &AudioTrackParameterLockPlayback
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for AudioTrackParameterLockPlayback
impl Clone for AudioTrackParameterLockPlayback
Sourcefn clone(&self) -> AudioTrackParameterLockPlayback
fn clone(&self) -> AudioTrackParameterLockPlayback
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioTrackParameterLockPlayback
Sourceimpl<'de> Deserialize<'de> for AudioTrackParameterLockPlayback
impl<'de> Deserialize<'de> for AudioTrackParameterLockPlayback
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AudioTrackParameterLockPlayback
Sourceimpl Ord for AudioTrackParameterLockPlayback
impl Ord for AudioTrackParameterLockPlayback
Sourcefn cmp(&self, other: &AudioTrackParameterLockPlayback) -> Ordering
fn cmp(&self, other: &AudioTrackParameterLockPlayback) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AudioTrackParameterLockPlayback
impl PartialOrd for AudioTrackParameterLockPlayback
impl StructuralPartialEq for AudioTrackParameterLockPlayback