MidiTrackTrigs

Struct MidiTrackTrigs 

pub struct MidiTrackTrigs {
    pub header: [u8; 4],
    pub unknown_1: [u8; 4],
    pub track_id: u8,
    pub trig_masks: MidiTrackTrigMasks,
    pub scale_per_track_mode: TrackPerTrackModeScale,
    pub swing_amount: u8,
    pub pattern_settings: TrackPatternSettings,
    pub plocks: Box<Array<MidiTrackParameterLocks, 64>>,
    pub trig_offsets_repeats_conditions: [[u8; 2]; 64],
}
Track trigs assigned on an Audio Track within a Pattern

Fields

header: [u8; 4]

Header data section

example data:

MTRA
4d 54 52 41
unknown_1: [u8; 4]

Unknown data.

track_id: u8

The zero indexed track number

trig_masks: MidiTrackTrigMasks

MIDI Track Trig masks contain the Trig step locations for different trig types

scale_per_track_mode: TrackPerTrackModeScale

The scale of this MIDI Track in Per Track Pattern mode.

swing_amount: u8

Amount of swing when a Swing Trig is active for the Track. Maximum is 30 (80 on device), minimum is 0 (50 on device).

pattern_settings: TrackPatternSettings

Pattern settings for this MIDI Track

plocks: Box<Array<MidiTrackParameterLocks, 64>>

trig properties – p-locks etc. the big 0xff value block within tracks basically. 32 bytes per trig – 6x parameters for 5x pages plus 2x extra fields at the end.

For audio tracks, the 2x extra fields at the end are for sample locks, but there’s no such concept for MIDI tracks. It seems like Elektron devs reused their data structures for P-Locks on both Audio + MIDI tracks.

trig_offsets_repeats_conditions: [[u8; 2]; 64]

See the documentation for AudioTrackTrigs on how this field works.