Pattern

Struct Pattern 

pub struct Pattern {
    pub header: [u8; 8],
    pub audio_track_trigs: Tracks<AudioTrackTrigs>,
    pub midi_track_trigs: Tracks<MidiTrackTrigs>,
    pub scale: PatternScaleSettings,
    pub chain_behaviour: PatternChainBehavior,
    pub unknown: u8,
    pub part_assignment: u8,
    pub tempo_1: u8,
    pub tempo_2: u8,
}
A pattern of trigs stored in the bank.

Fields

header: [u8; 8]

Header indicating start of pattern section

example data:

PTRN....
50 54 52 4e 00 00 00 00
audio_track_trigs: Tracks<AudioTrackTrigs>

Audio Track data

midi_track_trigs: Tracks<MidiTrackTrigs>

MIDI Track data

scale: PatternScaleSettings

Pattern scaling controls and settings

chain_behaviour: PatternChainBehavior

Pattern chaining behaviour and settings

unknown: u8

Unknown data.

part_assignment: u8

The Part of a Bank assigned to a Pattern. Part 1 = 0; Part 2 = 1; Part 3 = 2; Part 4 = 3. Credit to @sezare56 on elektronauts for catching this one

tempo_1: u8

Pattern setting for Tempo.

The Tempo value is split across both tempo_1 and tempo_2. Yet to figure out how they relate to each other.

Value of 120 BPM is 11 for this field. Value of 30 BPM is 2 for this field.

tempo_2: u8

Pattern setting for Tempo.

The Tempo value is split across both tempo_1 and tempo_2. Tet to figure out how they relate to each other.

Value of 120 BPM is 64 for this field. Value of 30 BPM is 208 for this field.