PatternScaleSettings

Struct PatternScaleSettings 

pub struct PatternScaleSettings {
    pub master_len_per_track_multiplier: u8,
    pub master_len_per_track: u8,
    pub master_scale_per_track: u8,
    pub master_len: u8,
    pub master_scale: u8,
    pub scale_mode: u8,
}
Pattern level scaling settings. Some of these settings still apply when the pattern is in Per-Track scaling mode.

Fields

master_len_per_track_multiplier: u8

Multiply this value by master_len_per_track to get the real Master Length in Per Track Pattern mode.

This field must be set to 255 when Master Length in Per Track Pattern mode is set to INF.

0: From 2 steps to 255 steps.
1: From 256 steps to 511 steps.
2: From 512 steps to 767 steps.
3: From 768 steps to 1023 steps.
4: 1024 steps only.
255: `INF`.
master_len_per_track: u8

Master Length in Per Track Pattern mode. Must multiply this by multiplier like this (x + 1) * (mult + 1) to get the real number.

This field must be set to 255 when Master Length in Per Track Pattern mode is set to INF.

Minimum value is 2 when the multiplier equals 0.

master_scale_per_track: u8

The Audio Track’s Scale when Pattern is in Per Track mode.

Options

0 -> 2x
1 -> 3/2x
2 -> 1x (Default)
3 -> 3/4x
4 -> 1/2x
5 -> 1/4x
6 -> 1/8x
master_len: u8

Master Pattern Length. Determines Pattern Length for all Tracks when NOT in Per Track mode.

master_scale: u8

Master Pattern playback multiplier.

Options

0 -> 2x
1 -> 3/2x
2 -> 1x (Default)
3 -> 3/4x
4 -> 1/2x
5 -> 1/4x
6 -> 1/8x
scale_mode: u8

Scale mode for the Pattern.

Options

NORMAL: 0 (Default)
PER TRACK: 1