pub struct TrackPerTrackModeScale {
pub per_track_len: u8,
pub per_track_scale: u8,
}Expand description
Audio Track custom scaling when the Pattern is in PER TRACK scale mode.
Fields
per_track_len: u8The Audio Track’s Length when Pattern is in Per Track mode. Default: 16
per_track_scale: u8The Audio Track’s Scale when Pattern is in Per Track mode.
Options
0 -> 2x
1 -> 3/2x
2 -> 1x (Default)
3 -> 3/4x
4 -> 1/2x
5 -> 1/4x
6 -> 1/8xTrait Implementations
Sourceimpl AsMut<TrackPerTrackModeScale> for TrackPerTrackModeScale
impl AsMut<TrackPerTrackModeScale> for TrackPerTrackModeScale
Sourcefn as_mut(&mut self) -> &mut TrackPerTrackModeScale
fn as_mut(&mut self) -> &mut TrackPerTrackModeScale
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<TrackPerTrackModeScale> for TrackPerTrackModeScale
impl AsRef<TrackPerTrackModeScale> for TrackPerTrackModeScale
Sourcefn as_ref(&self) -> &TrackPerTrackModeScale
fn as_ref(&self) -> &TrackPerTrackModeScale
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for TrackPerTrackModeScale
impl Clone for TrackPerTrackModeScale
Sourcefn clone(&self) -> TrackPerTrackModeScale
fn clone(&self) -> TrackPerTrackModeScale
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TrackPerTrackModeScale
Sourceimpl Debug for TrackPerTrackModeScale
impl Debug for TrackPerTrackModeScale
Sourceimpl Default for TrackPerTrackModeScale
impl Default for TrackPerTrackModeScale
Sourceimpl<'de> Deserialize<'de> for TrackPerTrackModeScale
impl<'de> Deserialize<'de> for TrackPerTrackModeScale
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TrackPerTrackModeScale
Sourceimpl Hash for TrackPerTrackModeScale
impl Hash for TrackPerTrackModeScale
Sourceimpl Ord for TrackPerTrackModeScale
impl Ord for TrackPerTrackModeScale
Sourcefn cmp(&self, other: &TrackPerTrackModeScale) -> Ordering
fn cmp(&self, other: &TrackPerTrackModeScale) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TrackPerTrackModeScale
impl PartialEq for TrackPerTrackModeScale
Sourceimpl PartialOrd for TrackPerTrackModeScale
impl PartialOrd for TrackPerTrackModeScale
Sourceimpl Serialize for TrackPerTrackModeScale
impl Serialize for TrackPerTrackModeScale
impl StructuralPartialEq for TrackPerTrackModeScale