pub struct ProjectMetadata {
pub filetype: String,
pub project_version: u32,
pub os_version: String,
}Expand description
Project metadata read from a parsed Octatrack Project file
Fields
filetype: StringType of file (always a ‘project’).
Example ASCII data:
TYPE=OCTATRACK DPS-1 PROJECTproject_version: u32Unknown. Probably refers to an internal Elektron release version number.
Example ASCII data:
VERSION=19os_version: StringVersion of the Octatrack OS (that the project was created with?).
Example ASCII data:
OS_VERSION=R0177 1.40BTrait Implementations
Sourceimpl Clone for ProjectMetadata
impl Clone for ProjectMetadata
Sourcefn clone(&self) -> ProjectMetadata
fn clone(&self) -> ProjectMetadata
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectMetadata
impl Debug for ProjectMetadata
Sourceimpl Default for ProjectMetadata
impl Default for ProjectMetadata
Sourceimpl<'de> Deserialize<'de> for ProjectMetadata
impl<'de> Deserialize<'de> for ProjectMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProjectMetadata
impl PartialEq for ProjectMetadata
Sourceimpl Serialize for ProjectMetadata
impl Serialize for ProjectMetadata
impl StructuralPartialEq for ProjectMetadata