OsMetadata

Struct OsMetadata 

pub struct OsMetadata {
    pub filetype: String,
    pub project_version: u32,
    pub os_version: String,
}
Operating system metadata read from a project.* file. The octatrack checks these fields on project load/open to ensure:

  1. it is possible to load the project (the project is not from an unrecognised OS version where a patch has not yet been installed)
  2. the project is upgraded to run on a newer OS version (need to patch the project data files as tey were created with an older OS)

No Copy trait as we (currently) use the String type for several fields

Fields

filetype: String

Type of file (always a ‘project’).

Example ASCII data:

TYPE=OCTATRACK DPS-1 PROJECT
project_version: u32

Version of project.* data type in this file, a la the datatype_version field on other main file types (probably?)

Example ASCII data:

VERSION=19
os_version: String

Version of the Octatrack OS (that the project was created with?).

Example ASCII data:

OS_VERSION=R0177     1.40B