ProjectFile

Struct ProjectFile 

pub struct ProjectFile {
    pub metadata: OsMetadata,
    pub settings: Settings,
    pub states: State,
    pub slots: Slots<Option<SlotAttributes>>,
}
A parsed representation of an Octatrack Project file (project.work or project.strd).

Note: We derive serde::Deserialize and serde::Serialize on this (and all the included subtypes). But project files are actually string data being parsed directly without any serde-ing or bincode-ing. This may change in the future to custom Serialize/Deserialize implementations for string source file data. But that will only happen if i can work out how to differentiate between deserializing a yaml/json string and a raw data file’s string data (we use serde::de::Deserializer::is_human_readable for arrangements to differentiate between YAML/JSON and string data files, which is a problem here as we’ll be testing for the difference between YAML/JSON (string data) and String (string data).)

No Copy trait as neither OsMetadata nor SlotAttributes support the Copy trait

Fields

metadata: OsMetadata

Metadata key-value pairs from a Project file.

settings: Settings

Settings key-value pairs from a Project file.

states: State

States key-value pairs from a Project file.

slots: Slots<Option<SlotAttributes>>

Slots key-value pairs from a Project file.

Implementations

Source

impl ProjectFile

pub fn check_compatible_os_version(&self) -> Result<bool, OtToolsIoError>

Check to see if the ProjectFile has a valid OS version for the current version of this library. The OS version string is contained in the project.* file under the x.metadata.os_version field. Multiple OS versions could be supported at any one time.

let proj = ProjectFile::from_data_file(&path).unwrap();
assert!(proj.check_compatible_os_version().unwrap());