pub enum SampleAttributeLoopMode {
Off,
Normal,
PingPong,
}Expand description
Sample attributes Loop mode options. See Octatrack Manaul section 13.2.4 ATTRIBUTES
Variants
Off
Loop points are ignored and sample will never loop.
Normal
Loop by starting again at the loop start position once playback of the sample reaches loop end.
PingPong
Loop by continuously reversing once playback of the sample reaches loop end/loop start.