TrigCondition

Enum TrigCondition 

pub enum TrigCondition {
Show 65 variants None = 0, Fill = 1, NotFill = 2, Pre = 3, NotPre = 4, Nei = 5, NotNei = 6, First = 7, NotFirst = 8, Percent1 = 9, Percent2 = 10, Percent4 = 11, Percent6 = 12, Percent9 = 13, Percent13 = 14, Percent19 = 15, Percent25 = 16, Percent33 = 17, Percent41 = 18, Percent50 = 19, Percent59 = 20, Percent67 = 21, Percent75 = 22, Percent81 = 23, Percent87 = 24, Percent91 = 25, Percent94 = 26, Percent96 = 27, Percent98 = 28, Percent99 = 29, PatternT1R2 = 30, PatternT2R2 = 31, PatternT1R3 = 32, PatternT2R3 = 33, PatternT3R3 = 34, PatternT1R4 = 35, PatternT2R4 = 36, PatternT3R4 = 37, PatternT4R4 = 38, PatternT1R5 = 39, PatternT2R5 = 40, PatternT3R5 = 41, PatternT4R5 = 42, PatternT5R5 = 43, PatternT1R6 = 44, PatternT2R6 = 45, PatternT3R6 = 46, PatternT4R6 = 47, PatternT5R6 = 48, PatternT6R6 = 49, PatternT1R7 = 50, PatternT2R7 = 51, PatternT3R7 = 52, PatternT4R7 = 53, PatternT5R7 = 54, PatternT6R7 = 55, PatternT7R7 = 56, PatternT1R8 = 57, PatternT2R8 = 58, PatternT3R8 = 59, PatternT4R8 = 60, PatternT5R8 = 61, PatternT6R8 = 62, PatternT7R8 = 63, PatternT8R8 = 64,
}
Sample Slot options for Projects.

Variants



None = 0



Fill = 1

FILL is true (will activate the trig) when fill mode is active (see below).



NotFill = 2

… true when FILL is not.



Pre = 3

PRE is true if the most recently evaluated trig condition on the same track was true.



NotPre = 4

… true when PRE is not.



Nei = 5

true if the most recently evaluated trig condition on the neighbor track was true. The neighbor track is the track before the one being edited. For example, the neighbor track of track 4 is track 3. If no conditions exist on the neighbor track, the condition is false.



NotNei = 6

… true when NEI is not.



First = 7

only true the first time the pattern play (when looped).



NotFirst = 8

… true when 1st is not.



Percent1 = 9

probability condition. 1% chance of being true.



Percent2 = 10

probability condition. 2% chance of being true.



Percent4 = 11

probability condition. 4% chance of being true.



Percent6 = 12

probability condition. 6% chance of being true.



Percent9 = 13

probability condition. 9% chance of being true.



Percent13 = 14

probability condition. 13% chance of being true.



Percent19 = 15

probability condition. 19% chance of being true.



Percent25 = 16

probability condition. 25% chance of being true.



Percent33 = 17

probability condition. 33% chance of being true.



Percent41 = 18

probability condition. 41% chance of being true.



Percent50 = 19

probability condition. 50% chance of being true.



Percent59 = 20

probability condition. 59% chance of being true.



Percent67 = 21

probability condition. 67% chance of being true.



Percent75 = 22

probability condition. 75% chance of being true.



Percent81 = 23

probability condition. 81% chance of being true.



Percent87 = 24

probability condition. 87% chance of being true.



Percent91 = 25

probability condition. 91% chance of being true.



Percent94 = 26

probability condition. 94% chance of being true.



Percent96 = 27

probability condition. 96% chance of being true.



Percent98 = 28

probability condition. 98% chance of being true.



Percent99 = 29

probability condition. 99% chance of being true.



PatternT1R2 = 30

pattern loop 1 triggers, pattern loop 2 resets



PatternT2R2 = 31

pattern loop 2 triggers, pattern loop 2 resets



PatternT1R3 = 32

pattern loop 1 triggers, pattern loop 3 resets



PatternT2R3 = 33

pattern loop 2 triggers, pattern loop 3 resets



PatternT3R3 = 34

pattern loop 3 triggers, pattern loop 3 resets



PatternT1R4 = 35

pattern loop 1 triggers, pattern loop 4 resets



PatternT2R4 = 36

pattern loop 2 triggers, pattern loop 4 resets



PatternT3R4 = 37

pattern loop 3 triggers, pattern loop 4 resets



PatternT4R4 = 38

pattern loop 4 triggers, pattern loop 4 resets



PatternT1R5 = 39

pattern loop 1 triggers, pattern loop 5 resets



PatternT2R5 = 40

pattern loop 2 triggers, pattern loop 5 resets



PatternT3R5 = 41

pattern loop 3 triggers, pattern loop 5 resets



PatternT4R5 = 42

pattern loop 4 triggers, pattern loop 5 resets



PatternT5R5 = 43

pattern loop 5 triggers, pattern loop 5 resets



PatternT1R6 = 44

pattern loop 1 triggers, pattern loop 6 resets



PatternT2R6 = 45

pattern loop 2 triggers, pattern loop 6 resets



PatternT3R6 = 46

pattern loop 3 triggers, pattern loop 6 resets



PatternT4R6 = 47

pattern loop 4 triggers, pattern loop 6 resets



PatternT5R6 = 48

pattern loop 5 triggers, pattern loop 6 resets



PatternT6R6 = 49

pattern loop 6 triggers, pattern loop 6 resets



PatternT1R7 = 50

pattern loop 1 triggers, pattern loop 7 resets



PatternT2R7 = 51

pattern loop 2 triggers, pattern loop 7 resets



PatternT3R7 = 52

pattern loop 3 triggers, pattern loop 7 resets



PatternT4R7 = 53

pattern loop 4 triggers, pattern loop 7 resets



PatternT5R7 = 54

pattern loop 5 triggers, pattern loop 7 resets



PatternT6R7 = 55

pattern loop 6 triggers, pattern loop 7 resets



PatternT7R7 = 56

pattern loop 7 triggers, pattern loop 7 resets



PatternT1R8 = 57

pattern loop 1 triggers, pattern loop 8 resets



PatternT2R8 = 58

pattern loop 2 triggers, pattern loop 8 resets



PatternT3R8 = 59

pattern loop 3 triggers, pattern loop 8 resets



PatternT4R8 = 60

pattern loop 4 triggers, pattern loop 8 resets



PatternT5R8 = 61

pattern loop 5 triggers, pattern loop 8 resets



PatternT6R8 = 62

pattern loop 6 triggers, pattern loop 8 resets



PatternT7R8 = 63

pattern loop 7 triggers, pattern loop 8 resets



PatternT8R8 = 64

pattern loop 8 triggers, pattern loop 8 resets