pub trait CheckFileVersion {
// Required method
fn check_file_version(&self) -> Result<bool, Box<dyn Error>>;
}Expand description
Adds a method to verify if the data file version field is valid for the given type.
use ot_tools_io::{CheckFileVersion, OctatrackFileIO, BankFile};
// true for valid version values
assert!(BankFile::from_data_file(&path).unwrap().check_file_version().unwrap())