ActiveSlot

Struct ActiveSlot 

pub struct ActiveSlot<A, M>{
    pub attrs: A,
    pub marks: M,
}
Convenience type for combining SlotAttributes and SlotMarkers, or types which have the respective AsRef trait implemented. This essentially gives you a type representative of the Octatrack’s slot editing pages – all markers data and all attributes data.

Fields

attrs: Amarks: M

Implementations

Source

impl<A, M> ActiveSlot<A, M>

pub fn new(attrs: A, marks: M) -> Self

Creates a new ActiveSlot instance from the two component slots data types.

AsRef

This method accepts any input type where, for each respective argument, AsRef<SlotSlotAttributes> or AsRef<SlotSlotMarkers> has been implemented appropriately. Therefore, any type that can be AsRef’d into one of these types is accepted as the relevant argument.

SlotAttributes example
use ot_tools_io::types::ActiveSlot;
use ot_tools_io::types::SlotAttributes;
use ot_tools_io::types::SlotMarkers;

// example data
let attrs = SlotAttributes {
    slot_type: SlotType::Static,
    slot_id: 1,
    path: None,
    timestrech_mode: Default::default(),
    loop_mode: Default::default(),
    trig_quantization_mode: Default::default(),
    gain: 48,
    bpm: 2880
};

pub struct AttrsNewType(SlotAttributes);

impl AsRef<SlotAttributes> for AttrsNewType {
    fn as_ref(&self) -> &SlotAttributes {
        &self.0
    }
}

ActiveSlot::new(AttrsNewType(attrs), SlotMarkers::default());
SlotMarkers example
use ot_tools_io::types::SlotMarkers;
use ot_tools_io::types::ActiveSlot;

let marks = SlotMarkers::default();

pub struct MarksNewType(SlotMarkers);

impl AsRef<SlotMarkers> for MarksNewType {
    fn as_ref(&self) -> &SlotMarkers {
        &self.0
    }
}

// can use the type as an input here
ActiveSlot::new(attrs, MarksNewType(marks));
pub fn attrs(self) -> A

getter for attributes data

pub fn attrs_ref(&self) -> &A

pub fn marks(self) -> M

reference getter for markers data

pub fn marks_ref(&self) -> &M

reference getter for markers data

Source

impl<A, M> ActiveSlot<A, M>

pub fn attrs_mut(&mut self) -> &mut A

mutable reference getter for attributes data

pub fn marks_mut(&mut self) -> &mut M

mutable reference getter for markers data