pub struct ArrangeRows<T>(/* private fields */);Expand description
Generic array wrapper for ArrangeRows.
Example: Extending in your own code with custom inner types
use ot_tools_io::types::ArrangeRows;
use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;
#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct CustomReminder(String);
let mut my_arr_reminders = ArrangeRows::<CustomReminder>::default();
let first = my_arr_reminders.first_mut().ok_or(())?;
*first = CustomReminder(
String::from(
"imagine this is a long reminder value that goes on for longer than normally allowed"
)
);
// first one changed
assert_eq!(
my_arr_reminders[0],
CustomReminder(
String::from(
"imagine this is a long reminder value that goes on for longer than normally allowed"
)
)
);
// rest are default
assert_eq!(my_arr_reminders[1], CustomReminder::default());
// correct length
assert_eq!(my_arr_reminders.len(), 256);
Implementations