Arrangements

Struct Arrangements 

pub struct Arrangements<T>(/* private fields */);
Generic collection for ArrangementFiles.

Serialize/Deserialize

Neither Serialize nor Deserialize are implemented for this type.

Box (no Copy)

The inner array of this type is wrapped in a Box. – we cannot fit all ArrangementFiles on the stack. Unfortunately this means the type does not implement Copy.

Example: Extending in your own code with custom inner types

use std::path::PathBuf;
use ot_tools_io::types::Arrangements;

use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;

#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct BackupPath(PathBuf);

let mut my_backups = Arrangements::<BackupPath>::default();
let my_new_backup = BackupPath(PathBuf::from("some_path"));
let first = my_backups.first_mut().ok_or(())?;
*first = my_new_backup;

// first one changed
assert_eq!(my_backups[0], BackupPath(PathBuf::from("some_path")));
// rest are default
assert_eq!(my_backups[1], BackupPath::default());

// correct length
assert_eq!(my_backups.len(), 8);

Implementations

Source

impl<T> Arrangements<T>

pub fn new(value: [T; 8]) -> Self

pub fn new_boxed(value: Box<[T; 8]>) -> Self

Source

impl<T> Arrangements<T>

pub fn id_ref(&self, id: &ArrId) -> &T

Returns a reference to an element of the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

pub fn id_mut(&mut self, id: &ArrId) -> &mut T

Returns a mutable reference to an element the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

Source

impl<T: Copy> Arrangements<T>

pub fn id(self, id: &ArrId) -> T

Returns an owned element of the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

Source

impl<T> Arrangements<T>

pub fn unbox(self) -> [T; 8]

Returns an owned [T; 16] by “un-boxing” (dereferencing) the data

pub fn unbox_ref(&self) -> &[T; 8]

Returns a referenced [T; 16] by “un-boxing” (dereferencing) the data

pub fn unbox_mut(&mut self) -> &mut [T; 8]

Returns a mutably referenced [T; 16] by “un-boxing” (dereferencing) the data

Source

impl Arrangements<ArrangementFile>

Concrete implementation for ArrangementFile adds two methods for reading and writing a batch of files.

pub fn from_data_files<P>( dirpath: P, state: &SavedState, ) -> Result<Self, OtToolsIoError>
where PathBuf: From<P>,

Reads a collection of ArrangementFiles from a directory.

pub fn to_data_files<P>( &self, dirpath: P, state: &SavedState, skip_unchanged: bool, ) -> Result<(), OtToolsIoError>
where PathBuf: From<P>,

Writes a collection of ArrangementFiles to a directory.

Will skip writing a particular ArrangementFile if the skip_unchanged argument is true and the current ArrangementFile matches the data in the existing file on the file system.