pub struct Banks<T>(/* private fields */);Expand description
Generic collection for BankFiles.
Serialize/Deserialize
Neither Serialize nor Deserialize are implemented for this type.
Box (no Copy)
The inner array of this type is wrapped in a Box.
– we cannot fit all BankFiles on the stack.
Unfortunately this means the type does not implement Copy.
Example: Extending in your own code with custom inner types
use ot_tools_io::types::Banks;
use std::path::PathBuf;
use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;
#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct YamlPath(PathBuf);
let mut my_bank_yamls = Banks::<YamlPath>::default();
let first = my_bank_yamls.first_mut().ok_or(())?;
*first = YamlPath(PathBuf::from("some_path"));
// first one changed
assert_eq!(my_bank_yamls[0], YamlPath(PathBuf::from("some_path")));
// rest are default
assert_eq!(my_bank_yamls[1], YamlPath::default());
// correct length
assert_eq!(my_bank_yamls.len(), 16);
Implementations
Sourceimpl<T> Banks<T>
impl<T> Banks<T>
Sourceimpl<T> Banks<T>
impl<T> Banks<T>
Sourceimpl Banks<BankFile>
impl Banks<BankFile>
Sourcepub fn from_data_files<P>(
dirpath: P,
state: &SavedState,
) -> Result<Self, OtToolsIoError>
pub fn from_data_files<P>( dirpath: P, state: &SavedState, ) -> Result<Self, OtToolsIoError>
Reads a collection of BankFiles from a directory.
Sourcepub fn to_data_files<P>(
&self,
dirpath: P,
state: &SavedState,
skip_unchanged: bool,
) -> Result<(), OtToolsIoError>
pub fn to_data_files<P>( &self, dirpath: P, state: &SavedState, skip_unchanged: bool, ) -> Result<(), OtToolsIoError>