pub struct Parts<T>(/* private fields */);Expand description
Generic collection for Parts
Serialize/Deserialize
Serialize and Deserialize are implemented for this type.
Box (no Copy)
The inner array of this type is wrapped in a Box.
Fields within a Part already use a Box so we are forced to wrap the data in a Box here.
Example: Extending in your own code with custom inner types
use ot_tools_io::types::Parts;
use std::path::PathBuf;
use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;
#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct LongPartName(String);
let mut my_part_names = Parts::<LongPartName>::default();
let first = my_part_names.first_mut().ok_or(())?;
*first = LongPartName(String::from("My awesome part name that is too long on the octatrack"));
// first one changed
assert_eq!(
my_part_names[0],
LongPartName(
String::from("My awesome part name that is too long on the octatrack")
)
);
// rest are default
assert_eq!(my_part_names[1], LongPartName::default());
// correct length
assert_eq!(my_part_names.len(), 4);
Implementations
Sourceimpl<T> Parts<T>
impl<T> Parts<T>