Tracks

Struct Tracks 

pub struct Tracks<T>(/* private fields */);
Generic collection for data related to tracks, e.g. for Recording Buffers, Audio Track Trigs, MIDI Track Trigs and the like. Used by a lot of fields on the Part and Pattern types.

Copy (no Box)

This generic collection helper does not use Box and can be Copy.

Example: Using in your own code with custom inner types

use ot_tools_io::types::Tracks;
use ot_tools_io::Defaults;
use ot_tools_io_derive::ArrayDefaults;
use std::array::from_fn;

#[derive(Debug, PartialEq, Default, ArrayDefaults)]
pub struct SomeNumber(u8);

fn main() -> Result<(), ()> {
    let mut my_tracks = Tracks::<SomeNumber>::default();
    let first = my_tracks.first_mut().ok_or(())?;
    *first = SomeNumber(100);

    // first one changed
    assert_eq!(my_tracks[0], SomeNumber(100));
    // rest are default
    assert_eq!(my_tracks[1], SomeNumber(0));

    // correct length
    assert_eq!(my_tracks.len(), 8);

    Ok(())
}

Implementations

Source

impl<T> Tracks<T>

pub fn id_ref(&self, id: &TrackId) -> &T

Returns a reference to an element of the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

pub fn id_mut(&mut self, id: &TrackId) -> &mut T

Returns a mutable reference to an element the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

Source

impl<T: Copy> Tracks<T>

pub fn id(self, id: &TrackId) -> T

Returns an owned element of the array data

Panic-free

This method is panic-free as the id type is guaranteed to never exceed the max index of the underlying array.

Source

impl<T> Tracks<T>

pub fn new(value: [T; 8]) -> Self