pub struct Trigs<T>(/* private fields */);Expand description
Generic collection for data related to trigs.
Used in Patterns with parameter lock trig assignments and trig offset/repeat/conditions data.
Box (no-Copy)
Unfortunately serde requires that we wrap the inner array type of Trigs in a Box.
As a result, Trigs and any type that contains a Trigs type cannot implement the Copy trait.
Example: Using in your own code with custom inner types
use ot_tools_io::types::Trigs;
use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;
#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct SomeNumber(u8);
fn main() -> Result<(), ()> {
let mut my_trigs = Trigs::<SomeNumber>::default();
let first = my_trigs.first_mut().ok_or(())?;
*first = SomeNumber(100);
// first one changed
assert_eq!(my_trigs[0], SomeNumber(100));
// rest are default
assert_eq!(my_trigs[1], SomeNumber(0));
// correct length
assert_eq!(my_trigs.len(), 64);
Ok(())
}Implementations
Sourceimpl<T> Trigs<T>
impl<T> Trigs<T>