pub struct MarkersFile {
pub header: [u8; 21],
pub datatype_version: u8,
pub flex_slots: Box<Array<SlotMarkers, 136>>,
pub static_slots: Box<Array<SlotMarkers, 128>>,
pub checksum: u16,
}Expand description
The ‘markers’ file. Contains sample editor data for all slots in a project.
Fields
header: [u8; 21]datatype_version: u8version of data file. used in OS upgrades for patching files (and checks performed on files during loading of a project).
background / context
Got this error on the device when i messed up the default markers file
when i didn’t include the 4 (current value for 1.40B).
>>> 2025-04-24 22:06:00 ERROR Couldn't read from markers file ...
>>> '/test-set-bankcopy/PROJECT-BLANK/markers.work' ('INVALID FILESIZE')Additionally, Banks for projects created with 1.40X have a ‘version’ number of 23, while the LESSSELF/V1 project started with 1.25E has a version of 15.
So yep. These weird numbers are version numbers for the data types / structures / files.
flex_slots: Box<Array<SlotMarkers, 136>>flex slots playback data
static_slots: Box<Array<SlotMarkers, 128>>static slots playback data
checksum: u16Trait Implementations
Sourceimpl CheckFileIntegrity for MarkersFile
impl CheckFileIntegrity for MarkersFile
Sourcefn check_integrity(&self) -> Result<bool, OtToolsIoError>
fn check_integrity(&self) -> Result<bool, OtToolsIoError>
Sourceimpl Clone for MarkersFile
impl Clone for MarkersFile
Sourcefn clone(&self) -> MarkersFile
fn clone(&self) -> MarkersFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarkersFile
impl Debug for MarkersFile
Sourceimpl Default for MarkersFile
impl Default for MarkersFile
Sourceimpl<'de> Deserialize<'de> for MarkersFile
impl<'de> Deserialize<'de> for MarkersFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasChecksumField for MarkersFile
impl HasChecksumField for MarkersFile
Sourcefn calculate_checksum(&self) -> Result<u16, OtToolsIoError>
fn calculate_checksum(&self) -> Result<u16, OtToolsIoError>
Method for calculating the checksum value for types that have a checksum field Read more
Sourcefn check_checksum(&self) -> Result<bool, OtToolsIoError>
fn check_checksum(&self) -> Result<bool, OtToolsIoError>
Method to verify if checksum is valid in some data type.
See this thread. Read more
Sourceimpl HasFileVersionField for MarkersFile
impl HasFileVersionField for MarkersFile
Sourcefn check_file_version(&self) -> Result<bool, OtToolsIoError>
fn check_file_version(&self) -> Result<bool, OtToolsIoError>
Method to verify if the data file version field is valid for the given type. Read more
Sourceimpl HasHeaderField for MarkersFile
impl HasHeaderField for MarkersFile
Sourcefn check_header(&self) -> Result<bool, OtToolsIoError>
fn check_header(&self) -> Result<bool, OtToolsIoError>
Method to verify if header(s) are valid in some data.
See this thread. Read more
Sourceimpl IsDefault for MarkersFile
impl IsDefault for MarkersFile
Sourceimpl OctatrackFileIO for MarkersFile
impl OctatrackFileIO for MarkersFile
Sourcefn decode(bytes: &[u8]) -> Result<Self, OtToolsIoError>where
Self: Sized + for<'a> Deserialize<'a>,
fn decode(bytes: &[u8]) -> Result<Self, OtToolsIoError>where
Self: Sized + for<'a> Deserialize<'a>,
Sourcefn repr(&self, newlines: Option<bool>)where
Self: Debug,
fn repr(&self, newlines: Option<bool>)where
Self: Debug,
Read type from an Octatrack data file at path Read more
Sourcefn from_data_file(path: &Path) -> Result<Self, OtToolsIoError>
fn from_data_file(path: &Path) -> Result<Self, OtToolsIoError>
Read type from an Octatrack data file at path Read more
Sourcefn from_bytes(bytes: &[u8]) -> Result<Self, OtToolsIoError>
fn from_bytes(bytes: &[u8]) -> Result<Self, OtToolsIoError>
Read type from bytes Read more
Sourcefn to_data_file(&self, path: &Path) -> Result<(), OtToolsIoError>
fn to_data_file(&self, path: &Path) -> Result<(), OtToolsIoError>
Write type to an Octatrack data file at path Read more
Sourcefn from_yaml_file(path: &Path) -> Result<Self, OtToolsIoError>
fn from_yaml_file(path: &Path) -> Result<Self, OtToolsIoError>
Read type from a YAML file at path Read more
Sourcefn from_yaml_str(yaml: &str) -> Result<Self, OtToolsIoError>
fn from_yaml_str(yaml: &str) -> Result<Self, OtToolsIoError>
Read type from YAML string Read more
Sourcefn to_yaml_file(&self, path: &Path) -> Result<(), OtToolsIoError>
fn to_yaml_file(&self, path: &Path) -> Result<(), OtToolsIoError>
Write type to a YAML file at path Read more
Sourcefn to_yaml_string(&self) -> Result<String, OtToolsIoError>
fn to_yaml_string(&self) -> Result<String, OtToolsIoError>
Create YAML string from type Read more
Sourcefn from_json_file(path: &Path) -> Result<Self, OtToolsIoError>
fn from_json_file(path: &Path) -> Result<Self, OtToolsIoError>
Read type from a JSON file at path
Sourcefn from_json_str(json: &str) -> Result<Self, OtToolsIoError>
fn from_json_str(json: &str) -> Result<Self, OtToolsIoError>
Create type from JSON string Read more
Sourcefn to_json_file(&self, path: &Path) -> Result<(), OtToolsIoError>
fn to_json_file(&self, path: &Path) -> Result<(), OtToolsIoError>
Write type to a JSON file at path Read more
Sourcefn to_json_string(&self) -> Result<String, OtToolsIoError>
fn to_json_string(&self) -> Result<String, OtToolsIoError>
Create JSON string from type Read more
Sourceimpl PartialEq for MarkersFile
impl PartialEq for MarkersFile
Sourceimpl Serialize for MarkersFile
impl Serialize for MarkersFile
impl Eq for MarkersFile
impl StructuralPartialEq for MarkersFile