Struct MarkersFile

pub struct MarkersFile {
    pub header: [u8; 21],
    pub datatype_version: u8,
    pub flex_slots: Box<Array<SlotPlayback, 128>>,
    pub recorder_slots: Box<Array<SlotPlayback, 8>>,
    pub static_slots: Box<Array<SlotPlayback, 128>>,
    pub checksum: u16,
}
The ‘markers’ file. Contains sample editor data for all slots in a project.

Fields

header: [u8; 21]datatype_version: u8

version of data file. used in OS upgrades for patching files (and checks performed on files during loading of a project).

background / context

Got this error on the device when i messed up the default markers file when i didn’t include the 4 (current value for 1.40B).

>>> 2025-04-24 22:06:00 ERROR Couldn't read from markers file ...
>>> '/test-set-bankcopy/PROJECT-BLANK/markers.work' ('INVALID FILESIZE')

Additionally, Banks for projects created with 1.40X have a ‘version’ number of 23, while the LESSSELF/V1 project started with 1.25E has a version of 15.

So yep. These weird numbers are version numbers for the data types / structures / files.

flex_slots: Box<Array<SlotPlayback, 128>>

audio editor slots for flex slots

recorder_slots: Box<Array<SlotPlayback, 8>>

8x dedicated flex recording tracks

static_slots: Box<Array<SlotPlayback, 128>>

audio editor slots for static slots

checksum: u16