pub struct MarkersFile {
pub header: [u8; 21],
pub datatype_version: u8,
pub flex_slots: Box<Array<SlotPlayback, 128>>,
pub recorder_slots: Box<Array<SlotPlayback, 8>>,
pub static_slots: Box<Array<SlotPlayback, 128>>,
pub checksum: u16,
}Expand description
The ‘markers’ file. Contains sample editor data for all slots in a project.
Fields
header: [u8; 21]datatype_version: u8version of data file. used in OS upgrades for patching files (and checks performed on files during loading of a project).
background / context
Got this error on the device when i messed up the default markers file
when i didn’t include the 4 (current value for 1.40B).
>>> 2025-04-24 22:06:00 ERROR Couldn't read from markers file ...
>>> '/test-set-bankcopy/PROJECT-BLANK/markers.work' ('INVALID FILESIZE')Additionally, Banks for projects created with 1.40X have a ‘version’ number of 23, while the LESSSELF/V1 project started with 1.25E has a version of 15.
So yep. These weird numbers are version numbers for the data types / structures / files.
flex_slots: Box<Array<SlotPlayback, 128>>audio editor slots for flex slots
recorder_slots: Box<Array<SlotPlayback, 8>>8x dedicated flex recording tracks
static_slots: Box<Array<SlotPlayback, 128>>audio editor slots for static slots
checksum: u16Trait Implementations
Sourceimpl CalculateChecksum for MarkersFile
impl CalculateChecksum for MarkersFile
Sourceimpl CheckChecksum for MarkersFile
impl CheckChecksum for MarkersFile
Sourceimpl CheckHeader for MarkersFile
impl CheckHeader for MarkersFile
fn check_header(&self) -> bool
Sourceimpl CheckIntegrity for MarkersFile
impl CheckIntegrity for MarkersFile
Sourceimpl Clone for MarkersFile
impl Clone for MarkersFile
Sourcefn clone(&self) -> MarkersFile
fn clone(&self) -> MarkersFile
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarkersFile
impl Debug for MarkersFile
Sourceimpl Decode for MarkersFile
impl Decode for MarkersFile
Sourceimpl Default for MarkersFile
impl Default for MarkersFile
Sourceimpl<'de> Deserialize<'de> for MarkersFile
impl<'de> Deserialize<'de> for MarkersFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl IsDefault for MarkersFile
impl IsDefault for MarkersFile
fn is_default(&self) -> bool
Sourceimpl PartialEq for MarkersFile
impl PartialEq for MarkersFile
Sourceimpl Serialize for MarkersFile
impl Serialize for MarkersFile
Sourceimpl SwapBytes for MarkersFile
impl SwapBytes for MarkersFile
impl Eq for MarkersFile
impl StructuralPartialEq for MarkersFile