pub struct AudioTrackTrigMasks {
pub trigger: Tracks<u8>,
pub trigless: Tracks<u8>,
pub plock: Tracks<u8>,
pub oneshot: Tracks<u8>,
pub recorder: [u8; 32],
pub swing: Tracks<u8>,
pub slide: Tracks<u8>,
}Expand description
Trig bitmasks array for Audio Tracks.
Can be converted into an array of booleans using the get_track_trigs_from_bitmasks function.
Trig bitmask arrays have bitmasks stored in this order, which is slightly confusing (pay attention to the difference with 7 + 8!):
- 1st half of the 4th page
- 2nd half of the 4th page
- 1st half of the 3rd page
- 2nd half of the 3rd page
- 1st half of the 2nd page
- 2nd half of the 2nd page
- 2nd half of the 1st page
- 1st half of the 1st page
Bitmask values for trig positions
With single trigs in a half-page
positions
1 2 3 4 5 6 7 8 | mask value
----------------|-----------
- - - - - - - - | 0
x - - - - - - - | 1
- x - - - - - - | 2
- - x - - - - - | 4
- - - x - - - - | 8
- - - - x - - - | 16
- - - - - x - - | 32
- - - - - - x - | 64
- - - - - - - x | 128When there are multiple trigs in a half-page, the individual position values are summed together:
1 2 3 4 5 6 7 8 | mask value
----------------|-----------
x x - - - - - - | 1 + 2 = 3
x x x x - - - - | 1 + 2 + 4 + 8 = 15Fuller diagram of mask values
positions
1 2 3 4 5 6 7 8 | mask value
----------------|-----------
x - - - - - - - | 1
- x - - - - - - | 2
x x - - - - - - | 3
- - x - - - - - | 4
x - x - - - - - | 5
- x x - - - - - | 6
x x x - - - - - | 7
- - - x - - - - | 8
x - - x - - - - | 9
- x - x - - - - | 10
x x - x - - - - | 11
- - x x - - - - | 12
x - x x - - - - | 13
- x x x - - - - | 14
x x x x - - - - | 15
................|....
x x x x x x - - | 63
................|....
- - - - - - - x | 128
................|....
- x - x - x - x | 170
................|....
- - - - x x x x | 240
................|....
x x x x x x x x | 255Fields
trigger: Tracks<u8>Trigger Trig masks – indicate which Trigger Trigs are active. Base track Trig masks are stored backwards, meaning the first 8 Trig positions are the last bytes in this section.
trigless: Tracks<u8>Envelope Trig masks – indicate which Envelope Trigs are active.
See the description of the trig_trig_masks field for an
explanation of how the masking works.
plock: Tracks<u8>Parameter-Lock Trig masks – indicate which Parameter-Lock Trigs are active.
See the description of the trig_trig_masks field for an
explanation of how the masking works.
oneshot: Tracks<u8>Hold Trig masks – indicate which Hold Trigs are active.
See the description of the trig_trig_masks field for an
explanation of how the masking works.
recorder: [u8; 32]Recorder Trig masks – indicate which Recorder Trigs are active. These seem to function differently to the main Track Trig masks. Filling up Recorder Trigs on a Pattern results in a 32 length array instead of 8 length. Possible that the Trig type is stored in this array as well.
swing: Tracks<u8>Swing trigs Trig masks.
slide: Tracks<u8>Parameter Slide trigs Trig masks.