pub struct AudioTrackTrigs {
pub header: [u8; 4],
pub unknown_1: [u8; 4],
pub track_id: u8,
pub trig_masks: AudioTrackTrigMasks,
pub scale_per_track_mode: TrackPerTrackModeScale,
pub swing_amount: u8,
pub pattern_settings: TrackPatternSettings,
pub unknown_2: u8,
pub plocks: Trigs<AudioTrackParameterLocks>,
pub unknown_3: Trigs<u8>,
pub trig_offsets_repeats_conditions: Trigs<TrigRepeatsConditionsAndOffsets>,
}Expand description
Track trigs assigned on an Audio Track within a Pattern
No Copy trait on this type as the plocks field is the AudioTrackParameterLocks type,
which does not implement Copy
Fields
header: [u8; 4]Header data section
example data:
TRAC
54 52 41 43unknown_1: [u8; 4]Unknown data.
track_id: u8The zero indexed track number
trig_masks: AudioTrackTrigMasksTrig masks contain the Trig step locations for different trig types
scale_per_track_mode: TrackPerTrackModeScaleThe scale of this Audio Track in Per Track Pattern mode.
swing_amount: u8Amount of swing when a Swing Trig is active for the Track.
Maximum is 30 (80 on device), minimum is 0 (50 on device).
pattern_settings: TrackPatternSettingsPattern settings for this Audio Track
unknown_2: u8Unknown data.
plocks: Trigs<AudioTrackParameterLocks>Parameter-Lock data for all Trigs.
unknown_3: Trigs<u8>What the hell is this field?!?! It has to be something to do with trigs, but i have no idea what it could be.
trig_offsets_repeats_conditions: Trigs<TrigRepeatsConditionsAndOffsets>Trig Offsets, Trig Counts and Trig Conditions.
See the documentation for TrigRepeatsConditionsAndOffsets for a detailed explainer on
how this field works before attempting to use it!
Implementations
Sourceimpl AudioTrackTrigs
impl AudioTrackTrigs
pub fn track_id(&self) -> Option<TrackId>
pub fn trigs(self) -> AudioTrackTrigMasks
pub fn trigs_ref(&self) -> &AudioTrackTrigMasks
pub fn trigs_mut(&mut self) -> &mut AudioTrackTrigMasks
pub fn swing_amount(&self) -> u8
pub fn trig_conditions(&self) -> Trigs<TrigCondition>