pub struct ProjectSampleSlot {
pub sample_type: ProjectSampleSlotType,
pub slot_id: u8,
pub path: PathBuf,
pub trim_bars_x100: u16,
pub timestrech_mode: SampleAttributeTimestrechMode,
pub loop_mode: SampleAttributeLoopMode,
pub trig_quantization_mode: SampleAttributeTrigQuantizationMode,
pub gain: i8,
pub bpm: u16,
}Fields
sample_type: ProjectSampleSlotTypeType of sample: STATIC or FLEX
slot_id: u8String ID Number of the slot the sample is assigned to e.g. 001, 002, 003… Maximum of 128 entries for STATIC sample slots, but can be up to 136 for flex slots as there are 8 recorders + 128 flex slots.
path: PathBufRelative path to the file on the card from the project directory.
trim_bars_x100: u16Current bar trim (float). This is multiplied by 100 on the machine. This is not used for recording buffer ‘flex’ tracks.
timestrech_mode: SampleAttributeTimestrechModeCurrent SampleTimestrechModes setting for the specific slot. Example: TSMODE=2
loop_mode: SampleAttributeLoopModeCurrent SampleLoopModes setting for the specific slot.
trig_quantization_mode: SampleAttributeTrigQuantizationModeCurrent SampleTrigQuantizationModes setting for this specific slot.
This is not used for recording buffer ‘flex’ tracks.
gain: i8Sample gain. 48 is default as per sample attributes file. maximum 96, minimum 0.
bpm: u16BPM of the sample in this slot.
Implementations
Sourceimpl ProjectSampleSlot
impl ProjectSampleSlot
pub fn new( sample_type: ProjectSampleSlotType, slot_id: u8, path: PathBuf, trim_bars_x100: Option<u16>, timestretch_mode: Option<SampleAttributeTimestrechMode>, loop_mode: Option<SampleAttributeLoopMode>, trig_quantization_mode: Option<SampleAttributeTrigQuantizationMode>, gain: Option<i8>, bpm: Option<u16>, ) -> Result<Self, Box<dyn Error>>