pub struct OsMetadata {
pub filetype: String,
pub project_version: u32,
pub os_version: String,
}Expand description
Operating system metadata read from a project.* file.
The octatrack checks these fields on project load/open to ensure:
- it is possible to load the project (the project is not from an unrecognised OS version where a patch has not yet been installed)
- the project is upgraded to run on a newer OS version (need to patch the project data files as tey were created with an older OS)
No Copy trait as we (currently) use the String type for several fields
Fields
filetype: StringType of file (always a ‘project’).
Example ASCII data:
TYPE=OCTATRACK DPS-1 PROJECTproject_version: u32Version of project.* data type in this file, a la the datatype_version field on other main file types (probably?)
Example ASCII data:
VERSION=19os_version: StringVersion of the Octatrack OS (that the project was created with?).
Example ASCII data:
OS_VERSION=R0177 1.40BTrait Implementations
Sourceimpl AsMut<OsMetadata> for OsMetadata
impl AsMut<OsMetadata> for OsMetadata
Sourcefn as_mut(&mut self) -> &mut OsMetadata
fn as_mut(&mut self) -> &mut OsMetadata
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<OsMetadata> for OsMetadata
impl AsRef<OsMetadata> for OsMetadata
Sourcefn as_ref(&self) -> &OsMetadata
fn as_ref(&self) -> &OsMetadata
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for OsMetadata
impl Clone for OsMetadata
Sourcefn clone(&self) -> OsMetadata
fn clone(&self) -> OsMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OsMetadata
impl Debug for OsMetadata
Sourceimpl Default for OsMetadata
impl Default for OsMetadata
Sourceimpl<'de> Deserialize<'de> for OsMetadata
impl<'de> Deserialize<'de> for OsMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for OsMetadata
impl Display for OsMetadata
impl Eq for OsMetadata
Sourceimpl FromStr for OsMetadata
impl FromStr for OsMetadata
Sourceimpl Hash for OsMetadata
impl Hash for OsMetadata
Sourceimpl Ord for OsMetadata
impl Ord for OsMetadata
Sourcefn cmp(&self, other: &OsMetadata) -> Ordering
fn cmp(&self, other: &OsMetadata) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OsMetadata
impl PartialEq for OsMetadata
Sourceimpl PartialOrd for OsMetadata
impl PartialOrd for OsMetadata
Sourceimpl Serialize for OsMetadata
impl Serialize for OsMetadata
impl StructuralPartialEq for OsMetadata