pub struct SlotAttributes {
pub slot_type: SlotType,
pub slot_id: u8,
pub path: Option<PathBuf>,
pub timestrech_mode: TimeStretchMode,
pub loop_mode: LoopMode,
pub trig_quantization_mode: TrigQuantizationMode,
pub gain: u8,
pub bpm: u16,
}Expand description
A sample slot’s global playback settings – trig quantization, bpm, timestrech mode … anything applied to the sample globally . The Octatrack only stores data when an audio file has been assigned to a sample slot.
Naming
The Octatrack manual specifically refers to
SAVE SAMPLE SETTINGS will save the trim, slice and attribute settings in a separate file and link it to the sample currently being edited. – page 87
So … these are the SLOT ATTRIBUTES which are saved to a SETTINGS FILE.
Non-Copy
This type is non-Copy becaue of the path field (PathBuf).
It is super frustrating in downstream applications, but I can’t really do much about it without
- abandonding the ability to transcode into YAML and JSON
- doing a hefty work-around where we decode into array data for the rust type
That last option is quite a lot of work as it is basically re-implementing OsString using
fixed array sizes, then writing abstractions for all path methods that we might want to use
on this “path that is really some fixed arrays, but we want everyone to think is a path”.
No-Default trait
It doesn’t make sense to have default field values for slot_type, slot_id or path.
Fields
slot_type: SlotTypeType of sample: STATIC or FLEX
slot_id: u8String ID Number of the slot the sample is assigned to e.g. 001, 002, 003… Maximum of 128 entries for STATIC sample slots, but can be up to 136 for flex slots as there are 8 recorders + 128 flex slots.
path: Option<PathBuf>Relative path to the file on the card from the project directory.
Recording buffer flex slots by default have an empty path attribute, which basically means ‘no path’. In idiomatic rust that’s an option.
timestrech_mode: TimeStretchModeCurrent TimestrechModes setting for the specific slot. Example: TSMODE=2
See TimeStretchMode.
loop_mode: LoopModeCurrent LoopMode setting for the specific slot.
See LoopMode.
trig_quantization_mode: TrigQuantizationModeCurrent TrigQuantizationModes setting for this specific slot.
This is not used for recording buffer ‘flex’ tracks.
See TrigQuantizationMode.
gain: u8Sample gain. 48 is default as per sample attributes file. maximum 96, minimum 0.
bpm: u16BPM of the sample in this slot. The stored representation is the ‘real’ bpm (float to 2 decimal places) multiplied by 24. Default value is 2880 (120 BPM). Max value is 7200 (300 BPM). Min value is 720 (30 BPM).
Implementations
Sourceimpl SlotAttributes
impl SlotAttributes
pub fn new( slot_type: SlotType, slot_id: u8, path: Option<PathBuf>, timestretch_mode: Option<TimeStretchMode>, loop_mode: Option<LoopMode>, trig_quantization_mode: Option<TrigQuantizationMode>, gain: Option<u8>, bpm: Option<u16>, ) -> Result<Self, OtToolsIoError>
Sourcepub fn new_no_opts(
slot_type: SlotType,
slot_id: u8,
path: Option<PathBuf>,
) -> Result<Self, OtToolsIoError>
pub fn new_no_opts( slot_type: SlotType, slot_id: u8, path: Option<PathBuf>, ) -> Result<Self, OtToolsIoError>
“I don’t care about optional arguments, just let me create a SlotAttributes”