pub struct ActiveSlot<A, M>{
pub attrs: A,
pub marks: M,
}Expand description
Convenience type for combining SlotAttributes and SlotMarkers,
or types which have the respective AsRef trait implemented.
This essentially gives you a type representative of the Octatrack’s slot editing pages
– all markers data and all attributes data.
Fields
attrs: Amarks: MImplementations
Sourceimpl<A, M> ActiveSlot<A, M>
impl<A, M> ActiveSlot<A, M>
Sourcepub fn new(attrs: A, marks: M) -> Self
pub fn new(attrs: A, marks: M) -> Self
Creates a new ActiveSlot instance from the two component slots data types.
AsRef
This method accepts any input type where, for each respective argument,
AsRef<SlotSlotAttributes> or AsRef<SlotSlotMarkers> has been implemented appropriately.
Therefore, any type that can be AsRef’d into one of these types is accepted as the
relevant argument.
SlotAttributes example
use ot_tools_io::types::ActiveSlot;
use ot_tools_io::types::SlotAttributes;
use ot_tools_io::types::SlotMarkers;
// example data
let attrs = SlotAttributes {
slot_type: SlotType::Static,
slot_id: 1,
path: None,
timestrech_mode: Default::default(),
loop_mode: Default::default(),
trig_quantization_mode: Default::default(),
gain: 48,
bpm: 2880
};
pub struct AttrsNewType(SlotAttributes);
impl AsRef<SlotAttributes> for AttrsNewType {
fn as_ref(&self) -> &SlotAttributes {
&self.0
}
}
ActiveSlot::new(AttrsNewType(attrs), SlotMarkers::default());SlotMarkers example
use ot_tools_io::types::SlotMarkers;
use ot_tools_io::types::ActiveSlot;
let marks = SlotMarkers::default();
pub struct MarksNewType(SlotMarkers);
impl AsRef<SlotMarkers> for MarksNewType {
fn as_ref(&self) -> &SlotMarkers {
&self.0
}
}
// can use the type as an input here
ActiveSlot::new(attrs, MarksNewType(marks));pub fn attrs_ref(&self) -> &A
Sourceimpl<A, M> ActiveSlot<A, M>
impl<A, M> ActiveSlot<A, M>