pub struct Arrangements<T>(/* private fields */);Expand description
Generic collection for ArrangementFiles.
Serialize/Deserialize
Neither Serialize nor Deserialize are implemented for this type.
Box (no Copy)
The inner array of this type is wrapped in a Box.
– we cannot fit all ArrangementFiles on the stack.
Unfortunately this means the type does not implement Copy.
Example: Extending in your own code with custom inner types
use std::path::PathBuf;
use ot_tools_io::types::Arrangements;
use ot_tools_io::Defaults;
use ot_tools_io_derive::{ArrayDefaults, BoxedArrayDefaults};
use std::array::from_fn;
#[derive(Debug, PartialEq, Default, ArrayDefaults, BoxedArrayDefaults)]
pub struct BackupPath(PathBuf);
let mut my_backups = Arrangements::<BackupPath>::default();
let my_new_backup = BackupPath(PathBuf::from("some_path"));
let first = my_backups.first_mut().ok_or(())?;
*first = my_new_backup;
// first one changed
assert_eq!(my_backups[0], BackupPath(PathBuf::from("some_path")));
// rest are default
assert_eq!(my_backups[1], BackupPath::default());
// correct length
assert_eq!(my_backups.len(), 8);
Implementations
Sourceimpl<T> Arrangements<T>
impl<T> Arrangements<T>
Sourceimpl<T> Arrangements<T>
impl<T> Arrangements<T>
Sourceimpl<T: Copy> Arrangements<T>
impl<T: Copy> Arrangements<T>
Sourceimpl<T> Arrangements<T>
impl<T> Arrangements<T>
Sourceimpl Arrangements<ArrangementFile>
Concrete implementation for ArrangementFile adds two methods for reading and writing a
batch of files.
impl Arrangements<ArrangementFile>
Concrete implementation for ArrangementFile adds two methods for reading and writing a
batch of files.
Sourcepub fn from_data_files<P>(
dirpath: P,
state: &SavedState,
) -> Result<Self, OtToolsIoError>
pub fn from_data_files<P>( dirpath: P, state: &SavedState, ) -> Result<Self, OtToolsIoError>
Reads a collection of ArrangementFiles from a directory.
Sourcepub fn to_data_files<P>(
&self,
dirpath: P,
state: &SavedState,
skip_unchanged: bool,
) -> Result<(), OtToolsIoError>
pub fn to_data_files<P>( &self, dirpath: P, state: &SavedState, skip_unchanged: bool, ) -> Result<(), OtToolsIoError>
Writes a collection of ArrangementFiles to a directory.
Will skip writing a particular ArrangementFile if the
skip_unchanged argument is true and the current ArrangementFile
matches the data in the existing file on the file system.